# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: torchrec_predict.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import eas_prediction.pytorch_predict_pb2 as pytorch__predict__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='torchrec_predict.proto',
  package='com.alibaba.pairec.processor',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16torchrec_predict.proto\x12\x1c\x63om.alibaba.pairec.processor\x1a\x15pytorch_predict.proto\"\x8e\x01\n\rLongStringMap\x12L\n\tmap_field\x18\x01 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.LongStringMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\nLongIntMap\x12I\n\tmap_field\x18\x01 \x03(\x0b\x32\x36.com.alibaba.pairec.processor.LongIntMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x8a\x01\n\x0bLongLongMap\x12J\n\tmap_field\x18\x01 \x03(\x0b\x32\x37.com.alibaba.pairec.processor.LongLongMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x8c\x01\n\x0cLongFloatMap\x12K\n\tmap_field\x18\x01 \x03(\x0b\x32\x38.com.alibaba.pairec.processor.LongFloatMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x8e\x01\n\rLongDoubleMap\x12L\n\tmap_field\x18\x01 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.LongDoubleMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x92\x01\n\x0fStringStringMap\x12N\n\tmap_field\x18\x01 \x03(\x0b\x32;.com.alibaba.pairec.processor.StringStringMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x0cStringIntMap\x12K\n\tmap_field\x18\x01 \x03(\x0b\x32\x38.com.alibaba.pairec.processor.StringIntMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x8e\x01\n\rStringLongMap\x12L\n\tmap_field\x18\x01 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.StringLongMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x90\x01\n\x0eStringFloatMap\x12M\n\tmap_field\x18\x01 \x03(\x0b\x32:.com.alibaba.pairec.processor.StringFloatMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x92\x01\n\x0fStringDoubleMap\x12N\n\tmap_field\x18\x01 \x03(\x0b\x32;.com.alibaba.pairec.processor.StringDoubleMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x8c\x01\n\x0cIntStringMap\x12K\n\tmap_field\x18\x01 \x03(\x0b\x32\x38.com.alibaba.pairec.processor.IntStringMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\tIntIntMap\x12H\n\tmap_field\x18\x01 \x03(\x0b\x32\x35.com.alibaba.pairec.processor.IntIntMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x88\x01\n\nIntLongMap\x12I\n\tmap_field\x18\x01 \x03(\x0b\x32\x36.com.alibaba.pairec.processor.IntLongMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x8a\x01\n\x0bIntFloatMap\x12J\n\tmap_field\x18\x01 \x03(\x0b\x32\x37.com.alibaba.pairec.processor.IntFloatMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x8c\x01\n\x0cIntDoubleMap\x12K\n\tmap_field\x18\x01 \x03(\x0b\x32\x38.com.alibaba.pairec.processor.IntDoubleMap.MapFieldEntry\x1a/\n\rMapFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\"\x1b\n\x07IntList\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\x05\"\x1c\n\x08LongList\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\x03\"\x1d\n\tFloatList\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\x02\"\x1e\n\nDoubleList\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\x01\"\x1e\n\nStringList\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\t\"@\n\x08IntLists\x12\x34\n\x05lists\x18\x01 \x03(\x0b\x32%.com.alibaba.pairec.processor.IntList\"B\n\tLongLists\x12\x35\n\x05lists\x18\x01 \x03(\x0b\x32&.com.alibaba.pairec.processor.LongList\"D\n\nFloatLists\x12\x36\n\x05lists\x18\x01 \x03(\x0b\x32\'.com.alibaba.pairec.processor.FloatList\"F\n\x0b\x44oubleLists\x12\x37\n\x05lists\x18\x01 \x03(\x0b\x32(.com.alibaba.pairec.processor.DoubleList\"F\n\x0bStringLists\x12\x37\n\x05lists\x18\x01 \x03(\x0b\x32(.com.alibaba.pairec.processor.StringList\"\xaa\x0e\n\tPBFeature\x12\x15\n\x0bint_feature\x18\x01 \x01(\x05H\x00\x12\x16\n\x0clong_feature\x18\x02 \x01(\x03H\x00\x12\x18\n\x0estring_feature\x18\x03 \x01(\tH\x00\x12\x17\n\rfloat_feature\x18\x04 \x01(\x02H\x00\x12\x18\n\x0e\x64ouble_feature\x18\x05 \x01(\x01H\x00\x12\x46\n\x0flong_string_map\x18\x06 \x01(\x0b\x32+.com.alibaba.pairec.processor.LongStringMapH\x00\x12@\n\x0clong_int_map\x18\x07 \x01(\x0b\x32(.com.alibaba.pairec.processor.LongIntMapH\x00\x12\x42\n\rlong_long_map\x18\x08 \x01(\x0b\x32).com.alibaba.pairec.processor.LongLongMapH\x00\x12\x44\n\x0elong_float_map\x18\t \x01(\x0b\x32*.com.alibaba.pairec.processor.LongFloatMapH\x00\x12\x46\n\x0flong_double_map\x18\n \x01(\x0b\x32+.com.alibaba.pairec.processor.LongDoubleMapH\x00\x12J\n\x11string_string_map\x18\x0b \x01(\x0b\x32-.com.alibaba.pairec.processor.StringStringMapH\x00\x12\x44\n\x0estring_int_map\x18\x0c \x01(\x0b\x32*.com.alibaba.pairec.processor.StringIntMapH\x00\x12\x46\n\x0fstring_long_map\x18\r \x01(\x0b\x32+.com.alibaba.pairec.processor.StringLongMapH\x00\x12H\n\x10string_float_map\x18\x0e \x01(\x0b\x32,.com.alibaba.pairec.processor.StringFloatMapH\x00\x12J\n\x11string_double_map\x18\x0f \x01(\x0b\x32-.com.alibaba.pairec.processor.StringDoubleMapH\x00\x12\x44\n\x0eint_string_map\x18\x10 \x01(\x0b\x32*.com.alibaba.pairec.processor.IntStringMapH\x00\x12>\n\x0bint_int_map\x18\x11 \x01(\x0b\x32\'.com.alibaba.pairec.processor.IntIntMapH\x00\x12@\n\x0cint_long_map\x18\x12 \x01(\x0b\x32(.com.alibaba.pairec.processor.IntLongMapH\x00\x12\x42\n\rint_float_map\x18\x13 \x01(\x0b\x32).com.alibaba.pairec.processor.IntFloatMapH\x00\x12\x44\n\x0eint_double_map\x18\x14 \x01(\x0b\x32*.com.alibaba.pairec.processor.IntDoubleMapH\x00\x12\x39\n\x08int_list\x18\x15 \x01(\x0b\x32%.com.alibaba.pairec.processor.IntListH\x00\x12;\n\tlong_list\x18\x16 \x01(\x0b\x32&.com.alibaba.pairec.processor.LongListH\x00\x12?\n\x0bstring_list\x18\x17 \x01(\x0b\x32(.com.alibaba.pairec.processor.StringListH\x00\x12=\n\nfloat_list\x18\x18 \x01(\x0b\x32\'.com.alibaba.pairec.processor.FloatListH\x00\x12?\n\x0b\x64ouble_list\x18\x19 \x01(\x0b\x32(.com.alibaba.pairec.processor.DoubleListH\x00\x12;\n\tint_lists\x18\x1a \x01(\x0b\x32&.com.alibaba.pairec.processor.IntListsH\x00\x12=\n\nlong_lists\x18\x1b \x01(\x0b\x32\'.com.alibaba.pairec.processor.LongListsH\x00\x12\x41\n\x0cstring_lists\x18\x1c \x01(\x0b\x32).com.alibaba.pairec.processor.StringListsH\x00\x12?\n\x0b\x66loat_lists\x18\x1d \x01(\x0b\x32(.com.alibaba.pairec.processor.FloatListsH\x00\x12\x41\n\x0c\x64ouble_lists\x18\x1e \x01(\x0b\x32).com.alibaba.pairec.processor.DoubleListsH\x00\x42\x07\n\x05value\"L\n\x0f\x43ontextFeatures\x12\x39\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\'.com.alibaba.pairec.processor.PBFeature\"\xf0\x04\n\tPBRequest\x12\x13\n\x0b\x64\x65\x62ug_level\x18\x01 \x01(\x05\x12P\n\ruser_features\x18\x02 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.PBRequest.UserFeaturesEntry\x12\x10\n\x08item_ids\x18\x03 \x03(\t\x12V\n\x10\x63ontext_features\x18\x04 \x03(\x0b\x32<.com.alibaba.pairec.processor.PBRequest.ContextFeaturesEntry\x12\x17\n\x0f\x66\x61iss_neigh_num\x18\x05 \x01(\x05\x12P\n\ritem_features\x18\x06 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.PBRequest.ItemFeaturesEntry\x1a\\\n\x11UserFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.com.alibaba.pairec.processor.PBFeature:\x02\x38\x01\x1a\x65\n\x14\x43ontextFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.com.alibaba.pairec.processor.ContextFeatures:\x02\x38\x01\x1a\x62\n\x11ItemFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12<\n\x05value\x18\x02 \x01(\x0b\x32-.com.alibaba.pairec.processor.ContextFeatures:\x02\x38\x01\"\xd2\x03\n\nPBResponse\x12M\n\x0bmap_outputs\x18\x01 \x03(\x0b\x32\x38.com.alibaba.pairec.processor.PBResponse.MapOutputsEntry\x12Y\n\x11generate_features\x18\x02 \x03(\x0b\x32>.com.alibaba.pairec.processor.PBResponse.GenerateFeaturesEntry\x12O\n\x0craw_features\x18\x03 \x03(\x0b\x32\x39.com.alibaba.pairec.processor.PBResponse.RawFeaturesEntry\x12\x10\n\x08item_ids\x18\x04 \x03(\t\x1aJ\n\x0fMapOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.pytorch.eas.ArrayProto:\x02\x38\x01\x1a\x37\n\x15GenerateFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10RawFeaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')
  ,
  dependencies=[pytorch__predict__pb2.DESCRIPTOR,])




_LONGSTRINGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.LongStringMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.LongStringMap.MapFieldEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.LongStringMap.MapFieldEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=222,
)

_LONGSTRINGMAP = _descriptor.Descriptor(
  name='LongStringMap',
  full_name='com.alibaba.pairec.processor.LongStringMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.LongStringMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LONGSTRINGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=222,
)


_LONGINTMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.LongIntMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.LongIntMap.MapFieldEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.LongIntMap.MapFieldEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=361,
)

_LONGINTMAP = _descriptor.Descriptor(
  name='LongIntMap',
  full_name='com.alibaba.pairec.processor.LongIntMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.LongIntMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LONGINTMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=361,
)


_LONGLONGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.LongLongMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.LongLongMap.MapFieldEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.LongLongMap.MapFieldEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=502,
)

_LONGLONGMAP = _descriptor.Descriptor(
  name='LongLongMap',
  full_name='com.alibaba.pairec.processor.LongLongMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.LongLongMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LONGLONGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=502,
)


_LONGFLOATMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.LongFloatMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.LongFloatMap.MapFieldEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.LongFloatMap.MapFieldEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=645,
)

_LONGFLOATMAP = _descriptor.Descriptor(
  name='LongFloatMap',
  full_name='com.alibaba.pairec.processor.LongFloatMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.LongFloatMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LONGFLOATMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=645,
)


_LONGDOUBLEMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.LongDoubleMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.LongDoubleMap.MapFieldEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.LongDoubleMap.MapFieldEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=790,
)

_LONGDOUBLEMAP = _descriptor.Descriptor(
  name='LongDoubleMap',
  full_name='com.alibaba.pairec.processor.LongDoubleMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.LongDoubleMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LONGDOUBLEMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=790,
)


_STRINGSTRINGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.StringStringMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.StringStringMap.MapFieldEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.StringStringMap.MapFieldEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=939,
)

_STRINGSTRINGMAP = _descriptor.Descriptor(
  name='StringStringMap',
  full_name='com.alibaba.pairec.processor.StringStringMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.StringStringMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGSTRINGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=793,
  serialized_end=939,
)


_STRINGINTMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.StringIntMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.StringIntMap.MapFieldEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.StringIntMap.MapFieldEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1082,
)

_STRINGINTMAP = _descriptor.Descriptor(
  name='StringIntMap',
  full_name='com.alibaba.pairec.processor.StringIntMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.StringIntMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGINTMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=942,
  serialized_end=1082,
)


_STRINGLONGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.StringLongMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.StringLongMap.MapFieldEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.StringLongMap.MapFieldEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1227,
)

_STRINGLONGMAP = _descriptor.Descriptor(
  name='StringLongMap',
  full_name='com.alibaba.pairec.processor.StringLongMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.StringLongMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGLONGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1227,
)


_STRINGFLOATMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.StringFloatMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.StringFloatMap.MapFieldEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.StringFloatMap.MapFieldEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1374,
)

_STRINGFLOATMAP = _descriptor.Descriptor(
  name='StringFloatMap',
  full_name='com.alibaba.pairec.processor.StringFloatMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.StringFloatMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGFLOATMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1230,
  serialized_end=1374,
)


_STRINGDOUBLEMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.StringDoubleMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.StringDoubleMap.MapFieldEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.StringDoubleMap.MapFieldEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1523,
)

_STRINGDOUBLEMAP = _descriptor.Descriptor(
  name='StringDoubleMap',
  full_name='com.alibaba.pairec.processor.StringDoubleMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.StringDoubleMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGDOUBLEMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1523,
)


_INTSTRINGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.IntStringMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.IntStringMap.MapFieldEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.IntStringMap.MapFieldEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1666,
)

_INTSTRINGMAP = _descriptor.Descriptor(
  name='IntStringMap',
  full_name='com.alibaba.pairec.processor.IntStringMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.IntStringMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTSTRINGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1526,
  serialized_end=1666,
)


_INTINTMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.IntIntMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.IntIntMap.MapFieldEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.IntIntMap.MapFieldEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1756,
  serialized_end=1803,
)

_INTINTMAP = _descriptor.Descriptor(
  name='IntIntMap',
  full_name='com.alibaba.pairec.processor.IntIntMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.IntIntMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTINTMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1669,
  serialized_end=1803,
)


_INTLONGMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.IntLongMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.IntLongMap.MapFieldEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.IntLongMap.MapFieldEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1895,
  serialized_end=1942,
)

_INTLONGMAP = _descriptor.Descriptor(
  name='IntLongMap',
  full_name='com.alibaba.pairec.processor.IntLongMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.IntLongMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTLONGMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1942,
)


_INTFLOATMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.IntFloatMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.IntFloatMap.MapFieldEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.IntFloatMap.MapFieldEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2036,
  serialized_end=2083,
)

_INTFLOATMAP = _descriptor.Descriptor(
  name='IntFloatMap',
  full_name='com.alibaba.pairec.processor.IntFloatMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.IntFloatMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTFLOATMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1945,
  serialized_end=2083,
)


_INTDOUBLEMAP_MAPFIELDENTRY = _descriptor.Descriptor(
  name='MapFieldEntry',
  full_name='com.alibaba.pairec.processor.IntDoubleMap.MapFieldEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.IntDoubleMap.MapFieldEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.IntDoubleMap.MapFieldEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2179,
  serialized_end=2226,
)

_INTDOUBLEMAP = _descriptor.Descriptor(
  name='IntDoubleMap',
  full_name='com.alibaba.pairec.processor.IntDoubleMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_field', full_name='com.alibaba.pairec.processor.IntDoubleMap.map_field', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTDOUBLEMAP_MAPFIELDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2226,
)


_INTLIST = _descriptor.Descriptor(
  name='IntList',
  full_name='com.alibaba.pairec.processor.IntList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.IntList.features', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2228,
  serialized_end=2255,
)


_LONGLIST = _descriptor.Descriptor(
  name='LongList',
  full_name='com.alibaba.pairec.processor.LongList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.LongList.features', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2257,
  serialized_end=2285,
)


_FLOATLIST = _descriptor.Descriptor(
  name='FloatList',
  full_name='com.alibaba.pairec.processor.FloatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.FloatList.features', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2287,
  serialized_end=2316,
)


_DOUBLELIST = _descriptor.Descriptor(
  name='DoubleList',
  full_name='com.alibaba.pairec.processor.DoubleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.DoubleList.features', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2348,
)


_STRINGLIST = _descriptor.Descriptor(
  name='StringList',
  full_name='com.alibaba.pairec.processor.StringList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.StringList.features', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2350,
  serialized_end=2380,
)


_INTLISTS = _descriptor.Descriptor(
  name='IntLists',
  full_name='com.alibaba.pairec.processor.IntLists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='com.alibaba.pairec.processor.IntLists.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2382,
  serialized_end=2446,
)


_LONGLISTS = _descriptor.Descriptor(
  name='LongLists',
  full_name='com.alibaba.pairec.processor.LongLists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='com.alibaba.pairec.processor.LongLists.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2514,
)


_FLOATLISTS = _descriptor.Descriptor(
  name='FloatLists',
  full_name='com.alibaba.pairec.processor.FloatLists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='com.alibaba.pairec.processor.FloatLists.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2516,
  serialized_end=2584,
)


_DOUBLELISTS = _descriptor.Descriptor(
  name='DoubleLists',
  full_name='com.alibaba.pairec.processor.DoubleLists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='com.alibaba.pairec.processor.DoubleLists.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2656,
)


_STRINGLISTS = _descriptor.Descriptor(
  name='StringLists',
  full_name='com.alibaba.pairec.processor.StringLists',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lists', full_name='com.alibaba.pairec.processor.StringLists.lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2658,
  serialized_end=2728,
)


_PBFEATURE = _descriptor.Descriptor(
  name='PBFeature',
  full_name='com.alibaba.pairec.processor.PBFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_feature', full_name='com.alibaba.pairec.processor.PBFeature.int_feature', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_feature', full_name='com.alibaba.pairec.processor.PBFeature.long_feature', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_feature', full_name='com.alibaba.pairec.processor.PBFeature.string_feature', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_feature', full_name='com.alibaba.pairec.processor.PBFeature.float_feature', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_feature', full_name='com.alibaba.pairec.processor.PBFeature.double_feature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_string_map', full_name='com.alibaba.pairec.processor.PBFeature.long_string_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_int_map', full_name='com.alibaba.pairec.processor.PBFeature.long_int_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_long_map', full_name='com.alibaba.pairec.processor.PBFeature.long_long_map', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_float_map', full_name='com.alibaba.pairec.processor.PBFeature.long_float_map', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_double_map', full_name='com.alibaba.pairec.processor.PBFeature.long_double_map', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_string_map', full_name='com.alibaba.pairec.processor.PBFeature.string_string_map', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_int_map', full_name='com.alibaba.pairec.processor.PBFeature.string_int_map', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_long_map', full_name='com.alibaba.pairec.processor.PBFeature.string_long_map', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_float_map', full_name='com.alibaba.pairec.processor.PBFeature.string_float_map', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_double_map', full_name='com.alibaba.pairec.processor.PBFeature.string_double_map', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_string_map', full_name='com.alibaba.pairec.processor.PBFeature.int_string_map', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_int_map', full_name='com.alibaba.pairec.processor.PBFeature.int_int_map', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_long_map', full_name='com.alibaba.pairec.processor.PBFeature.int_long_map', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_float_map', full_name='com.alibaba.pairec.processor.PBFeature.int_float_map', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_double_map', full_name='com.alibaba.pairec.processor.PBFeature.int_double_map', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_list', full_name='com.alibaba.pairec.processor.PBFeature.int_list', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_list', full_name='com.alibaba.pairec.processor.PBFeature.long_list', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='com.alibaba.pairec.processor.PBFeature.string_list', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_list', full_name='com.alibaba.pairec.processor.PBFeature.float_list', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_list', full_name='com.alibaba.pairec.processor.PBFeature.double_list', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_lists', full_name='com.alibaba.pairec.processor.PBFeature.int_lists', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_lists', full_name='com.alibaba.pairec.processor.PBFeature.long_lists', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_lists', full_name='com.alibaba.pairec.processor.PBFeature.string_lists', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_lists', full_name='com.alibaba.pairec.processor.PBFeature.float_lists', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_lists', full_name='com.alibaba.pairec.processor.PBFeature.double_lists', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBFeature.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2731,
  serialized_end=4565,
)


_CONTEXTFEATURES = _descriptor.Descriptor(
  name='ContextFeatures',
  full_name='com.alibaba.pairec.processor.ContextFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='com.alibaba.pairec.processor.ContextFeatures.features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4567,
  serialized_end=4643,
)


_PBREQUEST_USERFEATURESENTRY = _descriptor.Descriptor(
  name='UserFeaturesEntry',
  full_name='com.alibaba.pairec.processor.PBRequest.UserFeaturesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBRequest.UserFeaturesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBRequest.UserFeaturesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4975,
  serialized_end=5067,
)

_PBREQUEST_CONTEXTFEATURESENTRY = _descriptor.Descriptor(
  name='ContextFeaturesEntry',
  full_name='com.alibaba.pairec.processor.PBRequest.ContextFeaturesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBRequest.ContextFeaturesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBRequest.ContextFeaturesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5069,
  serialized_end=5170,
)

_PBREQUEST_ITEMFEATURESENTRY = _descriptor.Descriptor(
  name='ItemFeaturesEntry',
  full_name='com.alibaba.pairec.processor.PBRequest.ItemFeaturesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBRequest.ItemFeaturesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBRequest.ItemFeaturesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5172,
  serialized_end=5270,
)

_PBREQUEST = _descriptor.Descriptor(
  name='PBRequest',
  full_name='com.alibaba.pairec.processor.PBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='debug_level', full_name='com.alibaba.pairec.processor.PBRequest.debug_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_features', full_name='com.alibaba.pairec.processor.PBRequest.user_features', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='com.alibaba.pairec.processor.PBRequest.item_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context_features', full_name='com.alibaba.pairec.processor.PBRequest.context_features', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faiss_neigh_num', full_name='com.alibaba.pairec.processor.PBRequest.faiss_neigh_num', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_features', full_name='com.alibaba.pairec.processor.PBRequest.item_features', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PBREQUEST_USERFEATURESENTRY, _PBREQUEST_CONTEXTFEATURESENTRY, _PBREQUEST_ITEMFEATURESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4646,
  serialized_end=5270,
)


_PBRESPONSE_MAPOUTPUTSENTRY = _descriptor.Descriptor(
  name='MapOutputsEntry',
  full_name='com.alibaba.pairec.processor.PBResponse.MapOutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBResponse.MapOutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBResponse.MapOutputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5556,
  serialized_end=5630,
)

_PBRESPONSE_GENERATEFEATURESENTRY = _descriptor.Descriptor(
  name='GenerateFeaturesEntry',
  full_name='com.alibaba.pairec.processor.PBResponse.GenerateFeaturesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBResponse.GenerateFeaturesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBResponse.GenerateFeaturesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5632,
  serialized_end=5687,
)

_PBRESPONSE_RAWFEATURESENTRY = _descriptor.Descriptor(
  name='RawFeaturesEntry',
  full_name='com.alibaba.pairec.processor.PBResponse.RawFeaturesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.alibaba.pairec.processor.PBResponse.RawFeaturesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.alibaba.pairec.processor.PBResponse.RawFeaturesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5689,
  serialized_end=5739,
)

_PBRESPONSE = _descriptor.Descriptor(
  name='PBResponse',
  full_name='com.alibaba.pairec.processor.PBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_outputs', full_name='com.alibaba.pairec.processor.PBResponse.map_outputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generate_features', full_name='com.alibaba.pairec.processor.PBResponse.generate_features', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_features', full_name='com.alibaba.pairec.processor.PBResponse.raw_features', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='com.alibaba.pairec.processor.PBResponse.item_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PBRESPONSE_MAPOUTPUTSENTRY, _PBRESPONSE_GENERATEFEATURESENTRY, _PBRESPONSE_RAWFEATURESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5273,
  serialized_end=5739,
)

_LONGSTRINGMAP_MAPFIELDENTRY.containing_type = _LONGSTRINGMAP
_LONGSTRINGMAP.fields_by_name['map_field'].message_type = _LONGSTRINGMAP_MAPFIELDENTRY
_LONGINTMAP_MAPFIELDENTRY.containing_type = _LONGINTMAP
_LONGINTMAP.fields_by_name['map_field'].message_type = _LONGINTMAP_MAPFIELDENTRY
_LONGLONGMAP_MAPFIELDENTRY.containing_type = _LONGLONGMAP
_LONGLONGMAP.fields_by_name['map_field'].message_type = _LONGLONGMAP_MAPFIELDENTRY
_LONGFLOATMAP_MAPFIELDENTRY.containing_type = _LONGFLOATMAP
_LONGFLOATMAP.fields_by_name['map_field'].message_type = _LONGFLOATMAP_MAPFIELDENTRY
_LONGDOUBLEMAP_MAPFIELDENTRY.containing_type = _LONGDOUBLEMAP
_LONGDOUBLEMAP.fields_by_name['map_field'].message_type = _LONGDOUBLEMAP_MAPFIELDENTRY
_STRINGSTRINGMAP_MAPFIELDENTRY.containing_type = _STRINGSTRINGMAP
_STRINGSTRINGMAP.fields_by_name['map_field'].message_type = _STRINGSTRINGMAP_MAPFIELDENTRY
_STRINGINTMAP_MAPFIELDENTRY.containing_type = _STRINGINTMAP
_STRINGINTMAP.fields_by_name['map_field'].message_type = _STRINGINTMAP_MAPFIELDENTRY
_STRINGLONGMAP_MAPFIELDENTRY.containing_type = _STRINGLONGMAP
_STRINGLONGMAP.fields_by_name['map_field'].message_type = _STRINGLONGMAP_MAPFIELDENTRY
_STRINGFLOATMAP_MAPFIELDENTRY.containing_type = _STRINGFLOATMAP
_STRINGFLOATMAP.fields_by_name['map_field'].message_type = _STRINGFLOATMAP_MAPFIELDENTRY
_STRINGDOUBLEMAP_MAPFIELDENTRY.containing_type = _STRINGDOUBLEMAP
_STRINGDOUBLEMAP.fields_by_name['map_field'].message_type = _STRINGDOUBLEMAP_MAPFIELDENTRY
_INTSTRINGMAP_MAPFIELDENTRY.containing_type = _INTSTRINGMAP
_INTSTRINGMAP.fields_by_name['map_field'].message_type = _INTSTRINGMAP_MAPFIELDENTRY
_INTINTMAP_MAPFIELDENTRY.containing_type = _INTINTMAP
_INTINTMAP.fields_by_name['map_field'].message_type = _INTINTMAP_MAPFIELDENTRY
_INTLONGMAP_MAPFIELDENTRY.containing_type = _INTLONGMAP
_INTLONGMAP.fields_by_name['map_field'].message_type = _INTLONGMAP_MAPFIELDENTRY
_INTFLOATMAP_MAPFIELDENTRY.containing_type = _INTFLOATMAP
_INTFLOATMAP.fields_by_name['map_field'].message_type = _INTFLOATMAP_MAPFIELDENTRY
_INTDOUBLEMAP_MAPFIELDENTRY.containing_type = _INTDOUBLEMAP
_INTDOUBLEMAP.fields_by_name['map_field'].message_type = _INTDOUBLEMAP_MAPFIELDENTRY
_INTLISTS.fields_by_name['lists'].message_type = _INTLIST
_LONGLISTS.fields_by_name['lists'].message_type = _LONGLIST
_FLOATLISTS.fields_by_name['lists'].message_type = _FLOATLIST
_DOUBLELISTS.fields_by_name['lists'].message_type = _DOUBLELIST
_STRINGLISTS.fields_by_name['lists'].message_type = _STRINGLIST
_PBFEATURE.fields_by_name['long_string_map'].message_type = _LONGSTRINGMAP
_PBFEATURE.fields_by_name['long_int_map'].message_type = _LONGINTMAP
_PBFEATURE.fields_by_name['long_long_map'].message_type = _LONGLONGMAP
_PBFEATURE.fields_by_name['long_float_map'].message_type = _LONGFLOATMAP
_PBFEATURE.fields_by_name['long_double_map'].message_type = _LONGDOUBLEMAP
_PBFEATURE.fields_by_name['string_string_map'].message_type = _STRINGSTRINGMAP
_PBFEATURE.fields_by_name['string_int_map'].message_type = _STRINGINTMAP
_PBFEATURE.fields_by_name['string_long_map'].message_type = _STRINGLONGMAP
_PBFEATURE.fields_by_name['string_float_map'].message_type = _STRINGFLOATMAP
_PBFEATURE.fields_by_name['string_double_map'].message_type = _STRINGDOUBLEMAP
_PBFEATURE.fields_by_name['int_string_map'].message_type = _INTSTRINGMAP
_PBFEATURE.fields_by_name['int_int_map'].message_type = _INTINTMAP
_PBFEATURE.fields_by_name['int_long_map'].message_type = _INTLONGMAP
_PBFEATURE.fields_by_name['int_float_map'].message_type = _INTFLOATMAP
_PBFEATURE.fields_by_name['int_double_map'].message_type = _INTDOUBLEMAP
_PBFEATURE.fields_by_name['int_list'].message_type = _INTLIST
_PBFEATURE.fields_by_name['long_list'].message_type = _LONGLIST
_PBFEATURE.fields_by_name['string_list'].message_type = _STRINGLIST
_PBFEATURE.fields_by_name['float_list'].message_type = _FLOATLIST
_PBFEATURE.fields_by_name['double_list'].message_type = _DOUBLELIST
_PBFEATURE.fields_by_name['int_lists'].message_type = _INTLISTS
_PBFEATURE.fields_by_name['long_lists'].message_type = _LONGLISTS
_PBFEATURE.fields_by_name['string_lists'].message_type = _STRINGLISTS
_PBFEATURE.fields_by_name['float_lists'].message_type = _FLOATLISTS
_PBFEATURE.fields_by_name['double_lists'].message_type = _DOUBLELISTS
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_feature'])
_PBFEATURE.fields_by_name['int_feature'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_feature'])
_PBFEATURE.fields_by_name['long_feature'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_feature'])
_PBFEATURE.fields_by_name['string_feature'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['float_feature'])
_PBFEATURE.fields_by_name['float_feature'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['double_feature'])
_PBFEATURE.fields_by_name['double_feature'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_string_map'])
_PBFEATURE.fields_by_name['long_string_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_int_map'])
_PBFEATURE.fields_by_name['long_int_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_long_map'])
_PBFEATURE.fields_by_name['long_long_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_float_map'])
_PBFEATURE.fields_by_name['long_float_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_double_map'])
_PBFEATURE.fields_by_name['long_double_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_string_map'])
_PBFEATURE.fields_by_name['string_string_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_int_map'])
_PBFEATURE.fields_by_name['string_int_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_long_map'])
_PBFEATURE.fields_by_name['string_long_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_float_map'])
_PBFEATURE.fields_by_name['string_float_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_double_map'])
_PBFEATURE.fields_by_name['string_double_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_string_map'])
_PBFEATURE.fields_by_name['int_string_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_int_map'])
_PBFEATURE.fields_by_name['int_int_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_long_map'])
_PBFEATURE.fields_by_name['int_long_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_float_map'])
_PBFEATURE.fields_by_name['int_float_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_double_map'])
_PBFEATURE.fields_by_name['int_double_map'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_list'])
_PBFEATURE.fields_by_name['int_list'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_list'])
_PBFEATURE.fields_by_name['long_list'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_list'])
_PBFEATURE.fields_by_name['string_list'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['float_list'])
_PBFEATURE.fields_by_name['float_list'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['double_list'])
_PBFEATURE.fields_by_name['double_list'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['int_lists'])
_PBFEATURE.fields_by_name['int_lists'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['long_lists'])
_PBFEATURE.fields_by_name['long_lists'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['string_lists'])
_PBFEATURE.fields_by_name['string_lists'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['float_lists'])
_PBFEATURE.fields_by_name['float_lists'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_PBFEATURE.oneofs_by_name['value'].fields.append(
  _PBFEATURE.fields_by_name['double_lists'])
_PBFEATURE.fields_by_name['double_lists'].containing_oneof = _PBFEATURE.oneofs_by_name['value']
_CONTEXTFEATURES.fields_by_name['features'].message_type = _PBFEATURE
_PBREQUEST_USERFEATURESENTRY.fields_by_name['value'].message_type = _PBFEATURE
_PBREQUEST_USERFEATURESENTRY.containing_type = _PBREQUEST
_PBREQUEST_CONTEXTFEATURESENTRY.fields_by_name['value'].message_type = _CONTEXTFEATURES
_PBREQUEST_CONTEXTFEATURESENTRY.containing_type = _PBREQUEST
_PBREQUEST_ITEMFEATURESENTRY.fields_by_name['value'].message_type = _CONTEXTFEATURES
_PBREQUEST_ITEMFEATURESENTRY.containing_type = _PBREQUEST
_PBREQUEST.fields_by_name['user_features'].message_type = _PBREQUEST_USERFEATURESENTRY
_PBREQUEST.fields_by_name['context_features'].message_type = _PBREQUEST_CONTEXTFEATURESENTRY
_PBREQUEST.fields_by_name['item_features'].message_type = _PBREQUEST_ITEMFEATURESENTRY
_PBRESPONSE_MAPOUTPUTSENTRY.fields_by_name['value'].message_type = pytorch__predict__pb2._ARRAYPROTO
_PBRESPONSE_MAPOUTPUTSENTRY.containing_type = _PBRESPONSE
_PBRESPONSE_GENERATEFEATURESENTRY.containing_type = _PBRESPONSE
_PBRESPONSE_RAWFEATURESENTRY.containing_type = _PBRESPONSE
_PBRESPONSE.fields_by_name['map_outputs'].message_type = _PBRESPONSE_MAPOUTPUTSENTRY
_PBRESPONSE.fields_by_name['generate_features'].message_type = _PBRESPONSE_GENERATEFEATURESENTRY
_PBRESPONSE.fields_by_name['raw_features'].message_type = _PBRESPONSE_RAWFEATURESENTRY
DESCRIPTOR.message_types_by_name['LongStringMap'] = _LONGSTRINGMAP
DESCRIPTOR.message_types_by_name['LongIntMap'] = _LONGINTMAP
DESCRIPTOR.message_types_by_name['LongLongMap'] = _LONGLONGMAP
DESCRIPTOR.message_types_by_name['LongFloatMap'] = _LONGFLOATMAP
DESCRIPTOR.message_types_by_name['LongDoubleMap'] = _LONGDOUBLEMAP
DESCRIPTOR.message_types_by_name['StringStringMap'] = _STRINGSTRINGMAP
DESCRIPTOR.message_types_by_name['StringIntMap'] = _STRINGINTMAP
DESCRIPTOR.message_types_by_name['StringLongMap'] = _STRINGLONGMAP
DESCRIPTOR.message_types_by_name['StringFloatMap'] = _STRINGFLOATMAP
DESCRIPTOR.message_types_by_name['StringDoubleMap'] = _STRINGDOUBLEMAP
DESCRIPTOR.message_types_by_name['IntStringMap'] = _INTSTRINGMAP
DESCRIPTOR.message_types_by_name['IntIntMap'] = _INTINTMAP
DESCRIPTOR.message_types_by_name['IntLongMap'] = _INTLONGMAP
DESCRIPTOR.message_types_by_name['IntFloatMap'] = _INTFLOATMAP
DESCRIPTOR.message_types_by_name['IntDoubleMap'] = _INTDOUBLEMAP
DESCRIPTOR.message_types_by_name['IntList'] = _INTLIST
DESCRIPTOR.message_types_by_name['LongList'] = _LONGLIST
DESCRIPTOR.message_types_by_name['FloatList'] = _FLOATLIST
DESCRIPTOR.message_types_by_name['DoubleList'] = _DOUBLELIST
DESCRIPTOR.message_types_by_name['StringList'] = _STRINGLIST
DESCRIPTOR.message_types_by_name['IntLists'] = _INTLISTS
DESCRIPTOR.message_types_by_name['LongLists'] = _LONGLISTS
DESCRIPTOR.message_types_by_name['FloatLists'] = _FLOATLISTS
DESCRIPTOR.message_types_by_name['DoubleLists'] = _DOUBLELISTS
DESCRIPTOR.message_types_by_name['StringLists'] = _STRINGLISTS
DESCRIPTOR.message_types_by_name['PBFeature'] = _PBFEATURE
DESCRIPTOR.message_types_by_name['ContextFeatures'] = _CONTEXTFEATURES
DESCRIPTOR.message_types_by_name['PBRequest'] = _PBREQUEST
DESCRIPTOR.message_types_by_name['PBResponse'] = _PBRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LongStringMap = _reflection.GeneratedProtocolMessageType('LongStringMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _LONGSTRINGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongStringMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _LONGSTRINGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongStringMap)
  ))
_sym_db.RegisterMessage(LongStringMap)
_sym_db.RegisterMessage(LongStringMap.MapFieldEntry)

LongIntMap = _reflection.GeneratedProtocolMessageType('LongIntMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _LONGINTMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongIntMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _LONGINTMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongIntMap)
  ))
_sym_db.RegisterMessage(LongIntMap)
_sym_db.RegisterMessage(LongIntMap.MapFieldEntry)

LongLongMap = _reflection.GeneratedProtocolMessageType('LongLongMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _LONGLONGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongLongMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _LONGLONGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongLongMap)
  ))
_sym_db.RegisterMessage(LongLongMap)
_sym_db.RegisterMessage(LongLongMap.MapFieldEntry)

LongFloatMap = _reflection.GeneratedProtocolMessageType('LongFloatMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _LONGFLOATMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongFloatMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _LONGFLOATMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongFloatMap)
  ))
_sym_db.RegisterMessage(LongFloatMap)
_sym_db.RegisterMessage(LongFloatMap.MapFieldEntry)

LongDoubleMap = _reflection.GeneratedProtocolMessageType('LongDoubleMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _LONGDOUBLEMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongDoubleMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _LONGDOUBLEMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongDoubleMap)
  ))
_sym_db.RegisterMessage(LongDoubleMap)
_sym_db.RegisterMessage(LongDoubleMap.MapFieldEntry)

StringStringMap = _reflection.GeneratedProtocolMessageType('StringStringMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _STRINGSTRINGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringStringMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _STRINGSTRINGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringStringMap)
  ))
_sym_db.RegisterMessage(StringStringMap)
_sym_db.RegisterMessage(StringStringMap.MapFieldEntry)

StringIntMap = _reflection.GeneratedProtocolMessageType('StringIntMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _STRINGINTMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringIntMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _STRINGINTMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringIntMap)
  ))
_sym_db.RegisterMessage(StringIntMap)
_sym_db.RegisterMessage(StringIntMap.MapFieldEntry)

StringLongMap = _reflection.GeneratedProtocolMessageType('StringLongMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _STRINGLONGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringLongMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _STRINGLONGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringLongMap)
  ))
_sym_db.RegisterMessage(StringLongMap)
_sym_db.RegisterMessage(StringLongMap.MapFieldEntry)

StringFloatMap = _reflection.GeneratedProtocolMessageType('StringFloatMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _STRINGFLOATMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringFloatMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _STRINGFLOATMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringFloatMap)
  ))
_sym_db.RegisterMessage(StringFloatMap)
_sym_db.RegisterMessage(StringFloatMap.MapFieldEntry)

StringDoubleMap = _reflection.GeneratedProtocolMessageType('StringDoubleMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _STRINGDOUBLEMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringDoubleMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _STRINGDOUBLEMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringDoubleMap)
  ))
_sym_db.RegisterMessage(StringDoubleMap)
_sym_db.RegisterMessage(StringDoubleMap.MapFieldEntry)

IntStringMap = _reflection.GeneratedProtocolMessageType('IntStringMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTSTRINGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntStringMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _INTSTRINGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntStringMap)
  ))
_sym_db.RegisterMessage(IntStringMap)
_sym_db.RegisterMessage(IntStringMap.MapFieldEntry)

IntIntMap = _reflection.GeneratedProtocolMessageType('IntIntMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTINTMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntIntMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _INTINTMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntIntMap)
  ))
_sym_db.RegisterMessage(IntIntMap)
_sym_db.RegisterMessage(IntIntMap.MapFieldEntry)

IntLongMap = _reflection.GeneratedProtocolMessageType('IntLongMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTLONGMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntLongMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _INTLONGMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntLongMap)
  ))
_sym_db.RegisterMessage(IntLongMap)
_sym_db.RegisterMessage(IntLongMap.MapFieldEntry)

IntFloatMap = _reflection.GeneratedProtocolMessageType('IntFloatMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTFLOATMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntFloatMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _INTFLOATMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntFloatMap)
  ))
_sym_db.RegisterMessage(IntFloatMap)
_sym_db.RegisterMessage(IntFloatMap.MapFieldEntry)

IntDoubleMap = _reflection.GeneratedProtocolMessageType('IntDoubleMap', (_message.Message,), dict(

  MapFieldEntry = _reflection.GeneratedProtocolMessageType('MapFieldEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTDOUBLEMAP_MAPFIELDENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntDoubleMap.MapFieldEntry)
    ))
  ,
  DESCRIPTOR = _INTDOUBLEMAP,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntDoubleMap)
  ))
_sym_db.RegisterMessage(IntDoubleMap)
_sym_db.RegisterMessage(IntDoubleMap.MapFieldEntry)

IntList = _reflection.GeneratedProtocolMessageType('IntList', (_message.Message,), dict(
  DESCRIPTOR = _INTLIST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntList)
  ))
_sym_db.RegisterMessage(IntList)

LongList = _reflection.GeneratedProtocolMessageType('LongList', (_message.Message,), dict(
  DESCRIPTOR = _LONGLIST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongList)
  ))
_sym_db.RegisterMessage(LongList)

FloatList = _reflection.GeneratedProtocolMessageType('FloatList', (_message.Message,), dict(
  DESCRIPTOR = _FLOATLIST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.FloatList)
  ))
_sym_db.RegisterMessage(FloatList)

DoubleList = _reflection.GeneratedProtocolMessageType('DoubleList', (_message.Message,), dict(
  DESCRIPTOR = _DOUBLELIST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.DoubleList)
  ))
_sym_db.RegisterMessage(DoubleList)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), dict(
  DESCRIPTOR = _STRINGLIST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringList)
  ))
_sym_db.RegisterMessage(StringList)

IntLists = _reflection.GeneratedProtocolMessageType('IntLists', (_message.Message,), dict(
  DESCRIPTOR = _INTLISTS,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.IntLists)
  ))
_sym_db.RegisterMessage(IntLists)

LongLists = _reflection.GeneratedProtocolMessageType('LongLists', (_message.Message,), dict(
  DESCRIPTOR = _LONGLISTS,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.LongLists)
  ))
_sym_db.RegisterMessage(LongLists)

FloatLists = _reflection.GeneratedProtocolMessageType('FloatLists', (_message.Message,), dict(
  DESCRIPTOR = _FLOATLISTS,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.FloatLists)
  ))
_sym_db.RegisterMessage(FloatLists)

DoubleLists = _reflection.GeneratedProtocolMessageType('DoubleLists', (_message.Message,), dict(
  DESCRIPTOR = _DOUBLELISTS,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.DoubleLists)
  ))
_sym_db.RegisterMessage(DoubleLists)

StringLists = _reflection.GeneratedProtocolMessageType('StringLists', (_message.Message,), dict(
  DESCRIPTOR = _STRINGLISTS,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.StringLists)
  ))
_sym_db.RegisterMessage(StringLists)

PBFeature = _reflection.GeneratedProtocolMessageType('PBFeature', (_message.Message,), dict(
  DESCRIPTOR = _PBFEATURE,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBFeature)
  ))
_sym_db.RegisterMessage(PBFeature)

ContextFeatures = _reflection.GeneratedProtocolMessageType('ContextFeatures', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTFEATURES,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.ContextFeatures)
  ))
_sym_db.RegisterMessage(ContextFeatures)

PBRequest = _reflection.GeneratedProtocolMessageType('PBRequest', (_message.Message,), dict(

  UserFeaturesEntry = _reflection.GeneratedProtocolMessageType('UserFeaturesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBREQUEST_USERFEATURESENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBRequest.UserFeaturesEntry)
    ))
  ,

  ContextFeaturesEntry = _reflection.GeneratedProtocolMessageType('ContextFeaturesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBREQUEST_CONTEXTFEATURESENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBRequest.ContextFeaturesEntry)
    ))
  ,

  ItemFeaturesEntry = _reflection.GeneratedProtocolMessageType('ItemFeaturesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBREQUEST_ITEMFEATURESENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBRequest.ItemFeaturesEntry)
    ))
  ,
  DESCRIPTOR = _PBREQUEST,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBRequest)
  ))
_sym_db.RegisterMessage(PBRequest)
_sym_db.RegisterMessage(PBRequest.UserFeaturesEntry)
_sym_db.RegisterMessage(PBRequest.ContextFeaturesEntry)
_sym_db.RegisterMessage(PBRequest.ItemFeaturesEntry)

PBResponse = _reflection.GeneratedProtocolMessageType('PBResponse', (_message.Message,), dict(

  MapOutputsEntry = _reflection.GeneratedProtocolMessageType('MapOutputsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBRESPONSE_MAPOUTPUTSENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBResponse.MapOutputsEntry)
    ))
  ,

  GenerateFeaturesEntry = _reflection.GeneratedProtocolMessageType('GenerateFeaturesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBRESPONSE_GENERATEFEATURESENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBResponse.GenerateFeaturesEntry)
    ))
  ,

  RawFeaturesEntry = _reflection.GeneratedProtocolMessageType('RawFeaturesEntry', (_message.Message,), dict(
    DESCRIPTOR = _PBRESPONSE_RAWFEATURESENTRY,
    __module__ = 'torchrec_predict_pb2'
    # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBResponse.RawFeaturesEntry)
    ))
  ,
  DESCRIPTOR = _PBRESPONSE,
  __module__ = 'torchrec_predict_pb2'
  # @@protoc_insertion_point(class_scope:com.alibaba.pairec.processor.PBResponse)
  ))
_sym_db.RegisterMessage(PBResponse)
_sym_db.RegisterMessage(PBResponse.MapOutputsEntry)
_sym_db.RegisterMessage(PBResponse.GenerateFeaturesEntry)
_sym_db.RegisterMessage(PBResponse.RawFeaturesEntry)


_LONGSTRINGMAP_MAPFIELDENTRY._options = None
_LONGINTMAP_MAPFIELDENTRY._options = None
_LONGLONGMAP_MAPFIELDENTRY._options = None
_LONGFLOATMAP_MAPFIELDENTRY._options = None
_LONGDOUBLEMAP_MAPFIELDENTRY._options = None
_STRINGSTRINGMAP_MAPFIELDENTRY._options = None
_STRINGINTMAP_MAPFIELDENTRY._options = None
_STRINGLONGMAP_MAPFIELDENTRY._options = None
_STRINGFLOATMAP_MAPFIELDENTRY._options = None
_STRINGDOUBLEMAP_MAPFIELDENTRY._options = None
_INTSTRINGMAP_MAPFIELDENTRY._options = None
_INTINTMAP_MAPFIELDENTRY._options = None
_INTLONGMAP_MAPFIELDENTRY._options = None
_INTFLOATMAP_MAPFIELDENTRY._options = None
_INTDOUBLEMAP_MAPFIELDENTRY._options = None
_PBREQUEST_USERFEATURESENTRY._options = None
_PBREQUEST_CONTEXTFEATURESENTRY._options = None
_PBREQUEST_ITEMFEATURESENTRY._options = None
_PBRESPONSE_MAPOUTPUTSENTRY._options = None
_PBRESPONSE_GENERATEFEATURESENTRY._options = None
_PBRESPONSE_RAWFEATURESENTRY._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from eas_prediction.request import Request
from eas_prediction.torchrec_predict_pb2 import PBRequest, PBResponse,PBFeature

class TorchRecRequest(Request):
    """
    Request for tensorflow services whose input data is in format of protobuf,
    privide methods to generate the required protobuf object, and serialze it to string
    """

    def __init__(self):
        self.request_data = PBRequest()


    def __str__(self):
        return self.request_data


    def add_feed(self, data, dbg_lvl=0):
        self.request_data.ParseFromString(data)
        self.request_data.debug_level = dbg_lvl


    def set_debug_level(self, dbg_lvl=0):
        self.request_data.debug_level = dbg_lvl
        
    def add_feat(self, value, dtype):
        dtype=dtype.upper()
        feat = PBFeature()
        if value is None or ((isinstance(value, dict) or isinstance(value,list)) and len(value)==0):
            feat.string_feature = ""
        elif dtype == "STRING":
            feat.string_feature = value
        elif dtype == "FLOAT":
            feat.float_feature = value
        elif dtype == "DOUBLE":
            feat.double_feature = value
        elif dtype in ("BIGINT","INT64"):
            feat.long_feature = value
        elif dtype == "INT":
            feat.int_feature = value
        elif dtype in ("LIST<FLOAT>","LIST<STRING>","LIST<DOUBLE>","LIST<INT>","LIST<INT64>","LIST<BIGINT>",
                       "ARRAY<FLOAT>","ARRAY<STRING>","ARRAY<DOUBLE>","ARRAY<INT>","ARRAY<INT64>","ARRAY<BIGINT>"):
            if not isinstance(value, list):
                raise ValueError("Expected value to be a list for LIST<FLOAT> dtype")
            if dtype in ("LIST<STRING>","ARRAY<STRING>"):
                list_v = feat.string_list
            elif dtype in ("LIST<FLOAT>","ARRAY<FLOAT>"):
                list_v = feat.float_list
            elif dtype in ("LIST<DOUBLE>","ARRAY<DOUBLE>"):
                list_v = feat.double_list
            elif dtype in ("LIST<BIGINT>","LIST<INT64>","ARRAY<BIGINT>","ARRAY<INT64>"):
                list_v = feat.long_list
            elif dtype in ("LIST<INT>","ARRAY<INT>"):
                list_v = feat.int_list
            for v in value:
                list_v.features.append(v)
        elif dtype in ("MAP<INT,INT>","MAP<INT,INT64>","MAP<INT,BIGINT>","MAP<INT,STRING>","MAP<INT,FLOAT>","MAP<INT,DOUBLE>" ,
                       "MAP<INT64,INT>","MAP<INT64,INT64>","MAP<INT64,BIGINT>","MAP<INT64,STRING>","MAP<INT64,FLOAT>","MAP<INT64,DOUBLE>" ,
                       "MAP<BIGINT,INT>","MAP<BIGINT,INT64>","MAP<BIGINT,BIGINT>","MAP<BIGINT,STRING>","MAP<BIGINT,FLOAT>","MAP<BIGINT,DOUBLE>"
        ):
            if not isinstance(value, dict):
                raise ValueError("Expected value to be a dict for MAP<INT,INT> dtype")
            if dtype == "MAP<INT,INT>":
                map_v = feat.int_int_map.map_field
            elif dtype in ("MAP<INT,INT64>","MAP<INT,BIGINT>"):
                map_v = feat.int_long_map.map_field
            elif dtype == "MAP<INT,STRING>":
                map_v = feat.int_string_map.map_field
            elif dtype == "MAP<INT,FLOAT>":
                map_v = feat.int_float_map.map_field
            elif dtype == "MAP<INT,DOUBLE>":
                map_v = feat.int_double_map.map_field
            
            elif dtype in ("MAP<INT64,INT>","MAP<BIGINT,INT>"):
                map_v = feat.long_int_map.map_field
            elif dtype in ("MAP<INT64,INT64>","MAP<BIGINT,BIGINT>","MAP<INT64,BIGINT>","MAP<BIGINT,INT64>"):
                map_v = feat.long_long_map.map_field
            elif dtype in ("MAP<INT64,STRING>","MAP<BIGINT,STRING>"):
                map_v = feat.long_string_map.map_field
            elif dtype in ("MAP<INT64,FLOAT>","MAP<BIGINT,FLOAT>"):
                map_v = feat.long_float_map.map_field
            elif dtype in ("MAP<INT64,DOUBLE>","MAP<BIGINT,DOUBLE>"):
                map_v = feat.long_double_map.map_field
            
            for k, v in value.items():
                # dict in json,all key is str,must convert to int
                map_v[int(k)]=v
        elif dtype in ("MAP<STRING,INT>","MAP<STRING,INT64>","MAP<STRING,BIGINT>","MAP<STRING,STRING>","MAP<STRING,FLOAT>","MAP<STRING,DOUBLE>" 
        ):
            if not isinstance(value, dict):
                raise ValueError("Expected value to be a dict for MAP<INT,INT> dtype")
            if dtype == "MAP<STRING,INT>":
                map_v = feat.string_int_map.map_field
            elif dtype in ("MAP<STRING,INT64>","MAP<STRING,BIGINT>"):
                map_v = feat.string_long_map.map_field
            elif dtype == "MAP<STRING,STRING>":
                map_v = feat.string_string_map.map_field
            elif dtype == "MAP<STRING,FLOAT>":
                map_v = feat.string_float_map.map_field
            elif dtype == "MAP<STRING,DOUBLE>":
                map_v = feat.string_double_map.map_field
            for k, v in value.items():
                map_v[k]=v
        elif dtype in ("ARRAY<ARRAY<FLOAT>>","LIST<LIST<FLOAT>>"):
            if not isinstance(value, list) or not all(isinstance(sublist, list) for sublist in value):
                raise ValueError("Expected value to be a list of lists for ARRAY<ARRAY<FLOAT>> dtype")
            float_lists = feat.float_lists 
            for sublist in value:
                float_list = float_lists.lists.add()  
                float_list.features.extend(sublist)  
        else:
            raise ValueError("unsupport dtype:",dtype)
        return feat
    
    def add_user_fea(self, k, value, dtype):
        feat=self.add_feat(value,dtype)
        self.request_data.user_features[k].CopyFrom(feat)

    def add_context_fea(self,k,value,dtype):
        feat=self.add_feat(value,dtype)
        self.request_data.context_features[k].features.add().CopyFrom(feat)
    
    def add_item_fea(self,k,value,dtype):
        feat=self.add_feat(value,dtype)
        self.request_data.item_features[k].features.add().CopyFrom(feat)
               
    def add_item_id(self, k):
        self.request_data.item_ids.append(str(k))
    
    def set_faiss_neigh_num(self, k):
        self.request_data.faiss_neigh_num = k

    def to_string(self):
        """
        Serialize the request to string for transmission
        :return: the request data in format of string
        """
        return self.request_data.SerializeToString()

    def parse_response(self, response_data):
        """
        Parse the given response data in string format to the related TFResponse object
        :param response_data: the service response data in string format
        :return: the TFResponse object related the request
        """
        self.response = PBResponse()
        self.response.ParseFromString(response_data)
        return self.response

